@@ -3,3 +3,7 @@ from .._impl import (
     api_ids_WorkspaceId as WorkspaceId,
 )
 
+__all__ = [
+    'WorkspaceId',
+]
+
