@@ -3,6 +3,7 @@ from .._impl import (
     api_rids_AttachmentRid as AttachmentRid,
     api_rids_AutomaticCheckEvaluationRid as AutomaticCheckEvaluationRid,
     api_rids_ChunkRid as ChunkRid,
+    api_rids_ConnectAppRid as ConnectAppRid,
     api_rids_DataSourceRid as DataSourceRid,
     api_rids_DatasetRid as DatasetRid,
     api_rids_EdgeSyncSourceRid as EdgeSyncSourceRid,
@@ -23,6 +24,7 @@ __all__ = [
     'AttachmentRid',
     'AutomaticCheckEvaluationRid',
     'ChunkRid',
+    'ConnectAppRid',
     'DataSourceRid',
     'DatasetRid',
     'EdgeSyncSourceRid',
