@@ -19,7 +19,6 @@ from .._impl import (
     module_FunctionParameter as FunctionParameter,
     module_GetDerivedSeriesRequest as GetDerivedSeriesRequest,
     module_GetDerivedSeriesResponse as GetDerivedSeriesResponse,
-    module_GetModuleRequest as GetModuleRequest,
     module_LatestVersionStrategy as LatestVersionStrategy,
     module_Module as Module,
     module_ModuleApplication as ModuleApplication,
@@ -37,6 +36,7 @@ from .._impl import (
     module_RequestModuleNameRef as RequestModuleNameRef,
     module_RequestModuleRef as RequestModuleRef,
     module_RequestModuleRefVisitor as RequestModuleRefVisitor,
+    module_RequestModuleRidRef as RequestModuleRidRef,
     module_SearchModuleApplicationsQuery as SearchModuleApplicationsQuery,
     module_SearchModuleApplicationsQueryVisitor as SearchModuleApplicationsQueryVisitor,
     module_SearchModuleApplicationsRequest as SearchModuleApplicationsRequest,
@@ -47,8 +47,6 @@ from .._impl import (
     module_SearchModulesResponse as SearchModulesResponse,
     module_SearchModulesSortField as SearchModulesSortField,
     module_SearchModulesSortOptions as SearchModulesSortOptions,
-    module_UpdateModuleApplicationRequest as UpdateModuleApplicationRequest,
-    module_UpdateModuleApplicationResponse as UpdateModuleApplicationResponse,
     module_UpdateModuleRequest as UpdateModuleRequest,
     module_ValueType as ValueType,
     module_VariableName as VariableName,
@@ -76,7 +74,6 @@ __all__ = [
     'FunctionParameter',
     'GetDerivedSeriesRequest',
     'GetDerivedSeriesResponse',
-    'GetModuleRequest',
     'LatestVersionStrategy',
     'Module',
     'ModuleApplication',
@@ -93,6 +90,7 @@ __all__ = [
     'RequestModuleNameRef',
     'RequestModuleRef',
     'RequestModuleRefVisitor',
+    'RequestModuleRidRef',
     'SearchModuleApplicationsQuery',
     'SearchModuleApplicationsQueryVisitor',
     'SearchModuleApplicationsRequest',
@@ -103,8 +101,6 @@ __all__ = [
     'SearchModulesResponse',
     'SearchModulesSortField',
     'SearchModulesSortOptions',
-    'UpdateModuleApplicationRequest',
-    'UpdateModuleApplicationResponse',
     'UpdateModuleRequest',
     'ValueType',
     'VariableName',
