@@ -2,6 +2,8 @@
 from .._impl import (
     module_internal_BatchGetResolvedModuleDefinitionsRequest as BatchGetResolvedModuleDefinitionsRequest,
     module_internal_BatchGetResolvedModuleDefinitionsResponse as BatchGetResolvedModuleDefinitionsResponse,
+    module_internal_BatchGetUnresolvedModuleDefinitionsRequest as BatchGetUnresolvedModuleDefinitionsRequest,
+    module_internal_BatchGetUnresolvedModuleDefinitionsResponse as BatchGetUnresolvedModuleDefinitionsResponse,
     module_internal_InternalModuleService as InternalModuleService,
     module_internal_ModuleApplicationReference as ModuleApplicationReference,
     module_internal_ModuleComputeDefinition as ModuleComputeDefinition,
@@ -11,6 +13,8 @@ from .._impl import (
 __all__ = [
     'BatchGetResolvedModuleDefinitionsRequest',
     'BatchGetResolvedModuleDefinitionsResponse',
+    'BatchGetUnresolvedModuleDefinitionsRequest',
+    'BatchGetUnresolvedModuleDefinitionsResponse',
     'ModuleApplicationReference',
     'ModuleComputeDefinition',
     'ResolvedModuleVersionDefinition',
