@@ -2,6 +2,7 @@
 from .._impl import (
     scout_asset_api_AddDataScopesToAssetRequest as AddDataScopesToAssetRequest,
     scout_asset_api_Asset as Asset,
+    scout_asset_api_AssetSortField as AssetSortField,
     scout_asset_api_AssetSortOptions as AssetSortOptions,
     scout_asset_api_AssetTypeDataScopeConfig as AssetTypeDataScopeConfig,
     scout_asset_api_Channel as Channel,
@@ -22,13 +23,13 @@ from .._impl import (
     scout_asset_api_SearchTypesQueryVisitor as SearchTypesQueryVisitor,
     scout_asset_api_SearchTypesRequest as SearchTypesRequest,
     scout_asset_api_SearchTypesResponse as SearchTypesResponse,
-    scout_asset_api_SortField as SortField,
     scout_asset_api_SortKey as SortKey,
     scout_asset_api_SortKeyVisitor as SortKeyVisitor,
     scout_asset_api_SortProperty as SortProperty,
     scout_asset_api_TagConfig as TagConfig,
     scout_asset_api_TagConfigVisitor as TagConfigVisitor,
     scout_asset_api_Type as Type,
+    scout_asset_api_TypeSortField as TypeSortField,
     scout_asset_api_TypeSortOptions as TypeSortOptions,
     scout_asset_api_UpdateAssetRefNamesRequest as UpdateAssetRefNamesRequest,
     scout_asset_api_UpdateAssetRequest as UpdateAssetRequest,
@@ -41,6 +42,7 @@ from .._impl import (
 __all__ = [
     'AddDataScopesToAssetRequest',
     'Asset',
+    'AssetSortField',
     'AssetSortOptions',
     'AssetTypeDataScopeConfig',
     'Channel',
@@ -61,13 +63,13 @@ __all__ = [
     'SearchTypesQueryVisitor',
     'SearchTypesRequest',
     'SearchTypesResponse',
-    'SortField',
     'SortKey',
     'SortKeyVisitor',
     'SortProperty',
     'TagConfig',
     'TagConfigVisitor',
     'Type',
+    'TypeSortField',
     'TypeSortOptions',
     'UpdateAssetRefNamesRequest',
     'UpdateAssetRequest',
