@@ -110,6 +110,7 @@ from .._impl import (
     scout_compute_api_Enum1dArraySeriesVisitor as Enum1dArraySeriesVisitor,
     scout_compute_api_EnumAggregationFunction as EnumAggregationFunction,
     scout_compute_api_EnumBucket as EnumBucket,
+    scout_compute_api_EnumConstantResampleInterpolationConfiguration as EnumConstantResampleInterpolationConfiguration,
     scout_compute_api_EnumCountDuplicateSeries as EnumCountDuplicateSeries,
     scout_compute_api_EnumFilterOperator as EnumFilterOperator,
     scout_compute_api_EnumFilterRanges as EnumFilterRanges,
@@ -119,6 +120,9 @@ from .._impl import (
     scout_compute_api_EnumHistogramPlot as EnumHistogramPlot,
     scout_compute_api_EnumPlot as EnumPlot,
     scout_compute_api_EnumPoint as EnumPoint,
+    scout_compute_api_EnumResampleConfiguration as EnumResampleConfiguration,
+    scout_compute_api_EnumResampleInterpolationConfiguration as EnumResampleInterpolationConfiguration,
+    scout_compute_api_EnumResampleInterpolationConfigurationVisitor as EnumResampleInterpolationConfigurationVisitor,
     scout_compute_api_EnumResampleSeries as EnumResampleSeries,
     scout_compute_api_EnumSeries as EnumSeries,
     scout_compute_api_EnumSeriesEqualityRanges as EnumSeriesEqualityRanges,
@@ -216,6 +220,7 @@ from .._impl import (
     scout_compute_api_NumericAggregationFunction as NumericAggregationFunction,
     scout_compute_api_NumericApproximateFilterSeries as NumericApproximateFilterSeries,
     scout_compute_api_NumericBucket as NumericBucket,
+    scout_compute_api_NumericConstantResampleInterpolationConfiguration as NumericConstantResampleInterpolationConfiguration,
     scout_compute_api_NumericFilterTransformationSeries as NumericFilterTransformationSeries,
     scout_compute_api_NumericHistogramBucket as NumericHistogramBucket,
     scout_compute_api_NumericHistogramBucketStrategy as NumericHistogramBucketStrategy,
@@ -226,6 +231,9 @@ from .._impl import (
     scout_compute_api_NumericOutputField as NumericOutputField,
     scout_compute_api_NumericPlot as NumericPlot,
     scout_compute_api_NumericPoint as NumericPoint,
+    scout_compute_api_NumericResampleConfiguration as NumericResampleConfiguration,
+    scout_compute_api_NumericResampleInterpolationConfiguration as NumericResampleInterpolationConfiguration,
+    scout_compute_api_NumericResampleInterpolationConfigurationVisitor as NumericResampleInterpolationConfigurationVisitor,
     scout_compute_api_NumericResampleSeries as NumericResampleSeries,
     scout_compute_api_NumericSeries as NumericSeries,
     scout_compute_api_NumericSeriesVisitor as NumericSeriesVisitor,
@@ -278,9 +286,6 @@ from .._impl import (
     scout_compute_api_RangesNumericAggregation as RangesNumericAggregation,
     scout_compute_api_RangesSummary as RangesSummary,
     scout_compute_api_Reference as Reference,
-    scout_compute_api_ResampleConfiguration as ResampleConfiguration,
-    scout_compute_api_ResampleInterpolationConfiguration as ResampleInterpolationConfiguration,
-    scout_compute_api_ResampleInterpolationConfigurationVisitor as ResampleInterpolationConfigurationVisitor,
     scout_compute_api_RollingOperationSeries as RollingOperationSeries,
     scout_compute_api_RollingOperator as RollingOperator,
     scout_compute_api_RollingOperatorVisitor as RollingOperatorVisitor,
@@ -473,6 +478,7 @@ __all__ = [
     'Enum1dArraySeriesVisitor',
     'EnumAggregationFunction',
     'EnumBucket',
+    'EnumConstantResampleInterpolationConfiguration',
     'EnumCountDuplicateSeries',
     'EnumFilterOperator',
     'EnumFilterRanges',
@@ -482,6 +488,9 @@ __all__ = [
     'EnumHistogramPlot',
     'EnumPlot',
     'EnumPoint',
+    'EnumResampleConfiguration',
+    'EnumResampleInterpolationConfiguration',
+    'EnumResampleInterpolationConfigurationVisitor',
     'EnumResampleSeries',
     'EnumSeries',
     'EnumSeriesVisitor',
@@ -579,6 +588,7 @@ __all__ = [
     'NumericAggregationFunction',
     'NumericApproximateFilterSeries',
     'NumericBucket',
+    'NumericConstantResampleInterpolationConfiguration',
     'NumericFilterTransformationSeries',
     'NumericHistogramBucket',
     'NumericHistogramBucketStrategy',
@@ -589,6 +599,9 @@ __all__ = [
     'NumericOutputField',
     'NumericPlot',
     'NumericPoint',
+    'NumericResampleConfiguration',
+    'NumericResampleInterpolationConfiguration',
+    'NumericResampleInterpolationConfigurationVisitor',
     'NumericResampleSeries',
     'NumericSeries',
     'NumericSeriesVisitor',
@@ -641,9 +654,6 @@ __all__ = [
     'RangesNumericAggregation',
     'RangesSummary',
     'Reference',
-    'ResampleConfiguration',
-    'ResampleInterpolationConfiguration',
-    'ResampleInterpolationConfigurationVisitor',
     'RollingOperationSeries',
     'RollingOperator',
     'RollingOperatorVisitor',
