@@ -19,6 +19,7 @@ from .._impl import (
     scout_compute_resolved_api_CartesianNode as CartesianNode,
     scout_compute_resolved_api_CartesianNodeVisitor as CartesianNodeVisitor,
     scout_compute_resolved_api_ClickHouseSeriesResolutionDetails as ClickHouseSeriesResolutionDetails,
+    scout_compute_resolved_api_ConstantDefaultValueResampleInterpolationConfiguration as ConstantDefaultValueResampleInterpolationConfiguration,
     scout_compute_resolved_api_CumulativeSumSeriesNode as CumulativeSumSeriesNode,
     scout_compute_resolved_api_CurveFitDetails as CurveFitDetails,
     scout_compute_resolved_api_CurveFitDetailsVisitor as CurveFitDetailsVisitor,
@@ -112,6 +113,8 @@ from .._impl import (
     scout_compute_resolved_api_ResampleConfiguration as ResampleConfiguration,
     scout_compute_resolved_api_ResampleInterpolationConfiguration as ResampleInterpolationConfiguration,
     scout_compute_resolved_api_ResampleInterpolationConfigurationVisitor as ResampleInterpolationConfigurationVisitor,
+    scout_compute_resolved_api_ResampleInterpolationConstantDefaultValue as ResampleInterpolationConstantDefaultValue,
+    scout_compute_resolved_api_ResampleInterpolationConstantDefaultValueVisitor as ResampleInterpolationConstantDefaultValueVisitor,
     scout_compute_resolved_api_ResolvedNode as ResolvedNode,
     scout_compute_resolved_api_ResolvedNodeVisitor as ResolvedNodeVisitor,
     scout_compute_resolved_api_ResolvedSeries as ResolvedSeries,
@@ -180,6 +183,7 @@ __all__ = [
     'CartesianNode',
     'CartesianNodeVisitor',
     'ClickHouseSeriesResolutionDetails',
+    'ConstantDefaultValueResampleInterpolationConfiguration',
     'CumulativeSumSeriesNode',
     'CurveFitDetails',
     'CurveFitDetailsVisitor',
@@ -273,6 +277,8 @@ __all__ = [
     'ResampleConfiguration',
     'ResampleInterpolationConfiguration',
     'ResampleInterpolationConfigurationVisitor',
+    'ResampleInterpolationConstantDefaultValue',
+    'ResampleInterpolationConstantDefaultValueVisitor',
     'ResolvedNode',
     'ResolvedNodeVisitor',
     'ResolvedSeries',
