@@ -12,11 +12,36 @@ from .._impl import (
     scout_integrations_api_IntegrationRid as IntegrationRid,
     scout_integrations_api_IntegrationsService as IntegrationsService,
     scout_integrations_api_NotificationConfiguration as NotificationConfiguration,
+    scout_integrations_api_NotificationFilter as NotificationFilter,
     scout_integrations_api_OpsgenieIntegration as OpsgenieIntegration,
     scout_integrations_api_OpsgenieRegion as OpsgenieRegion,
     scout_integrations_api_SendMessageRequest as SendMessageRequest,
     scout_integrations_api_SimpleWebhookIntegration as SimpleWebhookIntegration,
+    scout_integrations_api_SlackInstanceType as SlackInstanceType,
     scout_integrations_api_SlackWebhookIntegration as SlackWebhookIntegration,
     scout_integrations_api_UpdateIntegrationRequest as UpdateIntegrationRequest,
 )
 
+__all__ = [
+    'CreateIntegrationDetails',
+    'CreateIntegrationDetailsVisitor',
+    'CreateIntegrationRequest',
+    'CreateOpsgenieIntegrationDetails',
+    'CreateSimpleWebhookDetails',
+    'GenerateSlackWebhookResponse',
+    'Integration',
+    'IntegrationDetails',
+    'IntegrationDetailsVisitor',
+    'IntegrationRid',
+    'NotificationConfiguration',
+    'NotificationFilter',
+    'OpsgenieIntegration',
+    'OpsgenieRegion',
+    'SendMessageRequest',
+    'SimpleWebhookIntegration',
+    'SlackInstanceType',
+    'SlackWebhookIntegration',
+    'UpdateIntegrationRequest',
+    'IntegrationsService',
+]
+
