@@ -3,3 +3,7 @@ from .._impl import (
     scout_plotting_TimestampType as TimestampType,
 )
 
+__all__ = [
+    'TimestampType',
+]
+
