@@ -19,6 +19,7 @@ from .._impl import (
     scout_rids_api_NotebookRid as NotebookRid,
     scout_rids_api_PendingReviewAlertState as PendingReviewAlertState,
     scout_rids_api_ProcedureExecutionRid as ProcedureExecutionRid,
+    scout_rids_api_SavedViewRid as SavedViewRid,
     scout_rids_api_SnapshotRid as SnapshotRid,
     scout_rids_api_TemplateRid as TemplateRid,
     scout_rids_api_TypeRid as TypeRid,
@@ -49,6 +50,7 @@ __all__ = [
     'NotebookRid',
     'PendingReviewAlertState',
     'ProcedureExecutionRid',
+    'SavedViewRid',
     'SnapshotRid',
     'TemplateRid',
     'TypeRid',
